<template>
  <a-card :bordered="false">
    <!-- 查询区域 -->
    <div class="table-page-search-wrapper">
      <a-form layout="inline" @keyup.enter.native="searchQuery">
        <a-row :gutter="24">
          <a-col
            :xl='6'
            :lg='7'
            :md='8'
            :sm='24'
          >
            <a-form-item label='单据号'>
              <j-input
                placeholder='单据号检索'
                v-model='queryParam.num'
              ></j-input>
            </a-form-item>
          </a-col>
          <a-col
            :xl='6'
            :lg='7'
            :md='8'
            :sm='24'
          >
            <a-form-item label='是否已确认结果'>
              <j-dict-select-tag
                allow-clear
                placeholder=""
                :triggerChange="true"
                dictCode="is_product"
                v-model='queryParam.isConfirm'
              />
            </a-form-item>
          </a-col>
        </a-row>
      </a-form>
    </div>
    <!-- 查询区域-END -->

    <!-- 操作按钮区域 -->
    <div class="table-operator">
      <a-button
                type='primary'
                @click='searchQuery'
                icon='search'
              >查询</a-button>
              <a-button
                type='primary'
                @click='searchReset'
                icon='reload'
                style='margin-left: 8px'
              >重置</a-button>
      <!-- <a-button @click="handleAdd" type="primary" icon="plus">新增</a-button>
      <a-button type="primary" icon="download" @click="handleExportXls('设备事故登记')">导出</a-button>
      <a-upload name="file" :showUploadList="false" :multiple="false" :headers="tokenHeader" :action="importExcelUrl" @change="handleImportExcel">
        <a-button type="primary" icon="import">导入</a-button>
      </a-upload> -->
      <!-- 高级查询区域 -->
      <!-- <j-super-query :fieldList="superFieldList" ref="superQueryModal" @handleSuperQuery="handleSuperQuery"></j-super-query>
      <a-dropdown v-if="selectedRowKeys.length > 0">
        <a-menu slot="overlay">
          <a-menu-item key="1" @click="batchDel"><a-icon type="delete"/>删除</a-menu-item>
        </a-menu>
        <a-button style="margin-left: 8px"> 批量操作 <a-icon type="down" /></a-button>
      </a-dropdown> -->
    </div>

    <!-- table区域-begin -->
    <div>
      <div class="ant-alert ant-alert-info" style="margin-bottom: 16px;">
        <i class="anticon anticon-info-circle ant-alert-icon"></i> 已选择 <a style="font-weight: 600">{{ selectedRowKeys.length }}</a>项
        <a style="margin-left: 24px" @click="onClearSelected">清空</a>
      </div>

      <a-table
        ref="table"
        size="middle"
        :scroll="{x:true}"
        bordered
        rowKey="id"
        :columns="columns"
        :dataSource="dataSource"
        :pagination="ipagination"
        :loading="loading"
        :rowSelection="{selectedRowKeys: selectedRowKeys, onChange: onSelectChange}"
        class="j-table-force-nowrap"
        @change="handleTableChange">

        <template slot="htmlSlot" slot-scope="text">
          <div v-html="text"></div>
        </template>
        <template slot="imgSlot" slot-scope="text,record">
          <span v-if="!text" style="font-size: 12px;font-style: italic;">无图片</span>
          <img v-else :src="getImgView(text)" :preview="record.id" height="25px" alt="" style="max-width:80px;font-size: 12px;font-style: italic;"/>
        </template>
        <template slot="fileSlot" slot-scope="text">
          <span v-if="!text" style="font-size: 12px;font-style: italic;">无文件</span>
          <a-button
            v-else
            :ghost="true"
            type="primary"
            icon="download"
            size="small"
            @click="downloadFile(text)">
            下载
          </a-button>
        </template>

        <span slot="action" slot-scope="text, record">
          <a @click="handleEdit(record)" v-if="record.isConfirm=='no'" v-has="'fault:update'">录入</a>
          <a-divider type="vertical" v-if="record.isConfirm=='no'"/>
          <a-popconfirm
            title="确认提交吗?"
            @confirm="() => handleSubmit(record)"
          >
          <a  v-if="record.isConfirm=='no'" v-has="'fault:update'">提交</a>
          </a-popconfirm>
          <a-divider type="vertical" v-if="record.isConfirm=='no'" />
          <a-popconfirm
            title="确认驳回吗?"
            @confirm="() => handleReject(record)"
          >
          <a v-if="record.isConfirm=='sub'" v-has="'fault:confirm'">驳回</a>
          </a-popconfirm>
          <a-divider type="vertical" v-if="record.isConfirm=='sub'" />
          <a-popconfirm
            title="确认结果并进入验收流程吗?"
            @confirm="() => handleConfirm(record)"
          >
            <a v-if="record.isConfirm=='sub'" v-has="'fault:confirm'">确认</a>
          </a-popconfirm>
          <a-divider type="vertical" />
          <a @click="handleDetail(record)">详情</a>
        </span>

      </a-table>
    </div>

    <fault-info-modal ref="modalForm" @ok="modalFormOk"></fault-info-modal>
  </a-card>
</template>

<script>

  import '@/assets/less/TableExpand.less'
  import { mixinDevice } from '@/utils/mixin'
  import { JeecgListMixin } from '@/mixins/JeecgListMixin'
  import FaultInfoModal from './modules/FaultInfoModal'
import { putAction } from '../../api/manage'

  export default {
    name: 'FaultInfoList',
    mixins:[JeecgListMixin, mixinDevice],
    components: {
      FaultInfoModal
    },
    data () {
      return {
        description: '设备事故登记管理页面',
        // 表头
        columns: [
          {
            title: '#',
            dataIndex: '',
            key:'rowIndex',
            width:60,
            align:"center",
            customRender:function (t,r,index) {
              return parseInt(index)+1;
            }
          },
          {
            title:'单据号',
            align:"center",
            dataIndex: 'num'
          },
          {
            title:'质量隐患确认单',
            align:"center",
            dataIndex: 'quanlityId_dictText'
          },
          {
            title:'生产单位',
            align:"center",
            dataIndex: 'departId_dictText'
          },
          {
            title:'设备名称',
            align:"center",
            dataIndex: 'equipName'
          },
          {
            title:'设备型号',
            align:"center",
            dataIndex: 'equipModel'
          },
          {
            title:'统一编号',
            align:"center",
            dataIndex: 'equipNum'
          },
          {
            title:'工区',
            align:"center",
            dataIndex: 'area1_dictText'
          },
          {
            title:'单元/工段',
            align:"center",
            dataIndex: 'area2'
          },
          {
            title:'维修费用',
            align:"center",
            dataIndex: 'cost'
          },
          {
            title:'操作者',
            align:"center",
            dataIndex: 'operator_dictText'
          },
          {
            title:'出生年月',
            align:"center",
            dataIndex: 'birthday'
          },
          {
            title:'工作时间',
            align:"center",
            dataIndex: 'workStartTime'
          },
          // {
          //   title:'操作员是否有操作证',
          //   align:"center",
          //   dataIndex: 'isCertificate'
          // },
          // {
          //   title:'是否断电重启',
          //   align:"center",
          //   dataIndex: 'isOutage'
          // },
          // {
          //   title:'加工过程中的变动因素',
          //   align:"center",
          //   dataIndex: 'factor'
          // },
          // {
          //   title:'具体更改内容',
          //   align:"center",
          //   dataIndex: 'modifyContent'
          // },
          // {
          //   title:'发生事故时设备所执行的程序',
          //   align:"center",
          //   dataIndex: 'equipmentProcess'
          // },
          // {
          //   title:'发生事故时的现象',
          //   align:"center",
          //   dataIndex: 'phenomenon'
          // },
          // {
          //   title:'采取措施1',
          //   align:"center",
          //   dataIndex: 'method1'
          // },
          // {
          //   title:'采取措施2',
          //   align:"center",
          //   dataIndex: 'method2'
          // },
          // {
          //   title:'采取措施3',
          //   align:"center",
          //   dataIndex: 'method3'
          // },
          // {
          //   title:'事故所造成的结果',
          //   align:"center",
          //   dataIndex: 'result'
          // },
          // {
          //   title:'开始检查时间',
          //   align:"center",
          //   dataIndex: 'startCheckTime',
          //   customRender:function (text) {
          //     return !text?"":(text.length>10?text.substr(0,10):text)
          //   }
          // },
          // {
          //   title:'发生事故后设备的状态',
          //   align:"center",
          //   dataIndex: 'equipmentStatus'
          // },
          // {
          //   title:'维修人员对事故的分析',
          //   align:"center",
          //   dataIndex: 'anlysis'
          // },
          // {
          //   title:'维修人员检查结果',
          //   align:"center",
          //   dataIndex: 'checkResult'
          // },
          // {
          //   title:'事故原因分析过程中所采取的相关行为',
          //   align:"center",
          //   dataIndex: 'active'
          // },
          // {
          //   title:'建议采取的措施及时间节点',
          //   align:"center",
          //   dataIndex: 'suggest'
          // },
          // {
          //   title:'事故发生原因分析的核对',
          //   align:"center",
          //   dataIndex: 'judgment'
          // },
          // {
          //   title:'不同的意见及分析',
          //   align:"center",
          //   dataIndex: 'differentJudgment'
          // },
          // {
          //   title:'整改措施',
          //   align:"center",
          //   dataIndex: 'updateMethod'
          // },
          // {
          //   title:'事故结论',
          //   align:"center",
          //   dataIndex: 'finalResult'
          // },
          // {
          //   title:'维修责任人',
          //   align:"center",
          //   dataIndex: 'engineer'
          // },
          // {
          //   title:'技术负责人',
          //   align:"center",
          //   dataIndex: 'mechanic'
          // },
          // {
          //   title:'工长',
          //   align:"center",
          //   dataIndex: 'workLeader'
          // },
          // {
          //   title:'中心主任',
          //   align:"center",
          //   dataIndex: 'centerLeader'
          // },
          // {
          //   title:'组长',
          //   align:"center",
          //   dataIndex: 'teamLeader'
          // },
          // {
          //   title:'维修站站长',
          //   align:"center",
          //   dataIndex: 'repairLeader'
          // },
          // {
          //   title:'管理室业务经理',
          //   align:"center",
          //   dataIndex: 'equipLeader'
          // },
          // {
          //   title:'运行保障部主管领导',
          //   align:"center",
          //   dataIndex: 'guaranteeLeader'
          // },
          {
            title: '操作',
            dataIndex: 'action',
            align:"center",
            fixed:"right",
            width:147,
            scopedSlots: { customRender: 'action' }
          }
        ],
        url: {
          list: "/li/faultInfo/list",
          delete: "/li/faultInfo/delete",
          deleteBatch: "/li/faultInfo/deleteBatch",
          exportXlsUrl: "/li/faultInfo/exportXls",
          importExcelUrl: "li/faultInfo/importExcel",
          confirm: "li/faultInfo/confirm"
          
        },
        dictOptions:{},
        superFieldList:[],
      }
    },
    created() {
    this.getSuperFieldList();
    },
    computed: {
      importExcelUrl: function(){
        return `${window._CONFIG['domianURL']}/${this.url.importExcelUrl}`;
      },
    },
    methods: {
      initDictConfig(){
      },
      getSuperFieldList(){
        let fieldList=[];
        fieldList.push({type:'string',value:'num',text:'编码'})
        fieldList.push({type:'string',value:'qId',text:'质量隐患确认单ID'})
        fieldList.push({type:'string',value:'cost',text:'维修费用'})
        fieldList.push({type:'string',value:'isCertificate',text:'操作员是否有操作证'})
        fieldList.push({type:'string',value:'isOutage',text:'是否断电重启'})
        fieldList.push({type:'string',value:'factor',text:'加工过程中的变动因素'})
        fieldList.push({type:'string',value:'modifyContent',text:'具体更改内容'})
        fieldList.push({type:'string',value:'equipmentProcess',text:'发生事故时设备所执行的程序'})
        fieldList.push({type:'string',value:'phenomenon',text:'发生事故时的现象'})
        fieldList.push({type:'string',value:'method1',text:'采取措施1'})
        fieldList.push({type:'string',value:'method2',text:'采取措施2'})
        fieldList.push({type:'string',value:'method3',text:'采取措施3'})
        fieldList.push({type:'string',value:'result',text:'事故所造成的结果'})
        fieldList.push({type:'date',value:'startCheckTime',text:'开始检查时间'})
        fieldList.push({type:'string',value:'equipmentStatus',text:'发生事故后设备的状态'})
        fieldList.push({type:'string',value:'anlysis',text:'维修人员对事故的分析'})
        fieldList.push({type:'string',value:'checkResult',text:'维修人员检查结果'})
        fieldList.push({type:'string',value:'active',text:'事故原因分析过程中所采取的相关行为'})
        fieldList.push({type:'string',value:'suggest',text:'建议采取的措施及时间节点'})
        fieldList.push({type:'string',value:'judgment',text:'事故发生原因分析的核对'})
        fieldList.push({type:'string',value:'differentJudgment',text:'不同的意见及分析'})
        fieldList.push({type:'string',value:'updateMethod',text:'整改措施'})
        fieldList.push({type:'string',value:'finalResult',text:'事故结论'})
        fieldList.push({type:'string',value:'operater',text:'操作者'})
        fieldList.push({type:'string',value:'engineer',text:'维修责任人'})
        fieldList.push({type:'string',value:'mechanic',text:'技术负责人'})
        fieldList.push({type:'string',value:'workLeader',text:'工长'})
        fieldList.push({type:'string',value:'centerLeader',text:'中心主任'})
        fieldList.push({type:'string',value:'teamLeader',text:'组长'})
        fieldList.push({type:'string',value:'repairLeader',text:'维修站站长'})
        fieldList.push({type:'string',value:'equipLeader',text:'管理室业务经理'})
        fieldList.push({type:'string',value:'guaranteeLeader',text:'运行保障部主管领导'})
        this.superFieldList = fieldList
      },
      handleConfirm(record) {
        record.isConfirm = 'yes';
        putAction(this.url.confirm, record).then(res => {
          if (res.result) {
            this.$message.success('确认成功');
            this.loadData();
          } else {
            this.$message.error('确认出现异常')
          }
        })
      },
      handleSubmit(record) {
        record.isConfirm = "sub";
        putAction(this.url.confirm, record).then(res => {
          if (res.result) {
            this.$message.success('提交成功');
            this.loadData();
          } else {
            this.$message.error('提交出现异常')
          }
        })
      },
      handleReject(record) {
        record.isConfirm = "no";
        putAction(this.url.confirm, record).then(res => {
          if (res.result) {
            this.$message.success('驳回成功');
            this.loadData();
          } else {
            this.$message.error('驳回出现异常')
          }
        })
      },
    }
  }
</script>
<style scoped>
  @import '~@assets/less/common.less';
</style>